
The documentation of Plumbery
=============================

.. toctree::
   :maxdepth: 2

   readme
   getting_started
   usage
   contributing
   coding
   history

Documentation extracted from the code itself
============================================

* :ref:`modindex`
* :ref:`genindex`

